Skip to contents

Based on the 2024 ANES data with derived variables and subset to people who completed both pre and post-election interviews

Usage

anes_2024

Format

A data frame with 4764 rows and 60 variables:

CaseID

double 2024 Time Series Case ID

Weight

double Post-election raked weight: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]

Stratum

double Stratum: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]

VarUnit

double PSU: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]

InterviewMode_Pre

Factor Mode of interview: pre-election interview

InterviewMode_Post

Factor Mode of interview: post-election interview

CampaignInterest

Factor PRE: How interested in following campaigns

VotedPres2020

Factor PRE: Did R vote for President in 2020 [revised]

VotedPres2020_selection

Factor PRE: Recall of last (2020) Presidential vote choice

PartyID

Factor PRE: SUMMARY: Party ID

TrustGovernment

Factor PRE: How often trust government in Washington to do what is right [revised]

TrustPeople

Factor PRE: How often can people be trusted

Age

double Respondent age on Election Day

RaceEth

Factor PRE: SUMMARY: R self-identified race/ethnicity

Sex

Factor PRE: What is R's sex? [revised]

Income

Factor PRE: SUMMARY: Total (household) income

EarlyVote

Factor PRE: Already voted in General Election

EarlyVoteGeneral

Factor PRE: Confirmation voted (early) in November 5 election

Post_Vote24

Factor POST: Did R vote in the 2024 election

Pre_VotePres24

Factor PRE: Did R vote for President

Post_VotePres24

Factor POST: Did R vote for President

VotedPres2024_selection

Factor PRE-POST: SUMMARY: 2024 PRESIDENTIAL VOTE

AgeGroup

Factor Respondent age on Election Day (categorized)

EducationGroup

Factor Highest level of education (categorized)

Income7

Factor PRE: SUMMARY: Total (household) income

EarlyVote2024

character PRE: DID R ALREADY VOTE

Voted2024

character Voted in 2024 election

VotedPres2024

character Voted for president in 2024 election

V240001

double 2024 Time Series Case ID

V240002a

double Mode of interview: pre-election interview

V240002b

double Mode of interview: post-election interview

V240108b

double Post-election raked weight: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]

V240108d

double Stratum: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]

V240108c

double PSU: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]

V241005

double PRE: How interested in following campaigns

V241103

double PRE: Did R vote for President in 2020 [revised]

V241104

double PRE: Recall of last (2020) Presidential vote choice

V241038

double PRE: Did R vote for President

V241221

double PRE: Party ID: Does R think of self as Democrat, Republican, or Independent

V241222

double PRE: Party Identification strong - Democrat Republican

V241223

double PRE: No Party Identification - closer to Democratic Party or Republican Party

V241227x

double PRE: SUMMARY: Party ID

V241229

double PRE: How often trust government in Washington to do what is right [revised]

V241234

double PRE: How often can people be trusted

V241458x

double PRE: SUMMARY: Respondent age on Election Day

V241463

double PRE: Highest level of education

V241499

double PRE: R: Are you Spanish, Hispanic, or Latino

V241501x

double PRE: SUMMARY: R self-identified race/ethnicity

V241550

double PRE: What is R's sex? [revised]

V241566x

double PRE: SUMMARY: Total (household) income

V242065

double POST: Did R vote in the 2024 election

V241035

double PRE: Already voted in General Election

V241036

double PRE: Confirmation voted (early) in November 5 election

V241037

double PRE: In what manner did R vote

V242051

double POST: Is R registered to vote

V242095x

double PRE-POST: SUMMARY: VOTER TURNOUT IN 2024

V242066

double POST: Did R vote for President

V241039

double PRE: For whom did R vote for President

V242067

double POST: For whom did R vote for President

V242096x

double PRE-POST: SUMMARY: 2024 PRESIDENTIAL VOTE