Based on the 2024 ANES data with derived variables and subset to people who completed both pre and post-election interviews
Format
A data frame with 4764 rows and 60 variables:
CaseIDdouble 2024 Time Series Case ID
Weightdouble Post-election raked weight: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]
Stratumdouble Stratum: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]
VarUnitdouble PSU: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]
InterviewMode_PreFactor Mode of interview: pre-election interview
InterviewMode_PostFactor Mode of interview: post-election interview
CampaignInterestFactor PRE: How interested in following campaigns
VotedPres2020Factor PRE: Did R vote for President in 2020 [revised]
VotedPres2020_selectionFactor PRE: Recall of last (2020) Presidential vote choice
PartyIDFactor PRE: SUMMARY: Party ID
TrustGovernmentFactor PRE: How often trust government in Washington to do what is right [revised]
TrustPeopleFactor PRE: How often can people be trusted
Agedouble Respondent age on Election Day
RaceEthFactor PRE: SUMMARY: R self-identified race/ethnicity
SexFactor PRE: What is R's sex? [revised]
IncomeFactor PRE: SUMMARY: Total (household) income
EarlyVoteFactor PRE: Already voted in General Election
EarlyVoteGeneralFactor PRE: Confirmation voted (early) in November 5 election
Post_Vote24Factor POST: Did R vote in the 2024 election
Pre_VotePres24Factor PRE: Did R vote for President
Post_VotePres24Factor POST: Did R vote for President
VotedPres2024_selectionFactor PRE-POST: SUMMARY: 2024 PRESIDENTIAL VOTE
AgeGroupFactor Respondent age on Election Day (categorized)
EducationGroupFactor Highest level of education (categorized)
Income7Factor PRE: SUMMARY: Total (household) income
EarlyVote2024character PRE: DID R ALREADY VOTE
Voted2024character Voted in 2024 election
VotedPres2024character Voted for president in 2024 election
V240001double 2024 Time Series Case ID
V240002adouble Mode of interview: pre-election interview
V240002bdouble Mode of interview: post-election interview
V240108bdouble Post-election raked weight: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]
V240108ddouble Stratum: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]
V240108cdouble PSU: Face-to-Face (FTF), Web, & 2016-2024 Panel samples combined [FINAL]
V241005double PRE: How interested in following campaigns
V241103double PRE: Did R vote for President in 2020 [revised]
V241104double PRE: Recall of last (2020) Presidential vote choice
V241038double PRE: Did R vote for President
V241221double PRE: Party ID: Does R think of self as Democrat, Republican, or Independent
V241222double PRE: Party Identification strong - Democrat Republican
V241223double PRE: No Party Identification - closer to Democratic Party or Republican Party
V241227xdouble PRE: SUMMARY: Party ID
V241229double PRE: How often trust government in Washington to do what is right [revised]
V241234double PRE: How often can people be trusted
V241458xdouble PRE: SUMMARY: Respondent age on Election Day
V241463double PRE: Highest level of education
V241499double PRE: R: Are you Spanish, Hispanic, or Latino
V241501xdouble PRE: SUMMARY: R self-identified race/ethnicity
V241550double PRE: What is R's sex? [revised]
V241566xdouble PRE: SUMMARY: Total (household) income
V242065double POST: Did R vote in the 2024 election
V241035double PRE: Already voted in General Election
V241036double PRE: Confirmation voted (early) in November 5 election
V241037double PRE: In what manner did R vote
V242051double POST: Is R registered to vote
V242095xdouble PRE-POST: SUMMARY: VOTER TURNOUT IN 2024
V242066double POST: Did R vote for President
V241039double PRE: For whom did R vote for President
V242067double POST: For whom did R vote for President
V242096xdouble PRE-POST: SUMMARY: 2024 PRESIDENTIAL VOTE